==> syslog-ng_3.3.5.orig.tar.xz: syslog-ng-3.3.5/lib/parser-expr-parser.c <==
/*
 * Copyright (c) 2002-2010 BalaBit IT Ltd, Budapest, Hungary
 * Copyright (c) 1998-2010 Balázs Scheidler
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * As an additional exemption you are allowed to compile & link against the
 * OpenSSL libraries as published by the OpenSSL project. See the file
 * COPYING for details.
 *
 */
#include "parser-expr-parser.h"
#include "logparser.h"
#include "parser-expr-grammar.h"

extern int parser_expr_debug;
int parser_expr_parse(CfgLexer *lexer, GList **node);

static CfgLexerKeyword parser_expr_keywords[] = {
  { "file",               KW_FILE },
  { NULL }
};

CfgParser parser_expr_parser =
{
#if ENABLE_DEBUG
  .debug_flag = &parser_expr_debug,
#endif
  .name = "parser expression",
  .context = LL_CONTEXT_PARSER,
  .keywords = parser_expr_keywords,
  .parse = (gint (*)(CfgLexer *, gpointer *, gpointer)) parser_expr_parse,
};

CFG_PARSER_IMPLEMENT_LEXER_BINDING(parser_expr_, GList **)

==> syslog-ng_3.3.9.orig.tar.xz: syslog-ng-3.3.9/lib/parser-expr-parser.c <==
/*
 * Copyright (c) 2002-2010 BalaBit IT Ltd, Budapest, Hungary
 * Copyright (c) 1998-2010 Balázs Scheidler
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * As an additional exemption you are allowed to compile & link against the
 * OpenSSL libraries as published by the OpenSSL project. See the file
 * COPYING for details.
 *
 */
#include "parser-expr-parser.h"
#include "logparser.h"
#include "parser-expr-grammar.h"

extern int parser_expr_debug;
int parser_expr_parse(CfgLexer *lexer, GList **node, gpointer arg);

static CfgLexerKeyword parser_expr_keywords[] = {
  { "file",               KW_FILE },
  { NULL }
};

CfgParser parser_expr_parser =
{
#if ENABLE_DEBUG
  .debug_flag = &parser_expr_debug,
#endif
  .name = "parser expression",
  .context = LL_CONTEXT_PARSER,
  .keywords = parser_expr_keywords,
  .parse = (gint (*)(CfgLexer *, gpointer *, gpointer)) parser_expr_parse,
};

CFG_PARSER_IMPLEMENT_LEXER_BINDING(parser_expr_, GList **)
